oceanum.datamesh.Query — oceanum 0.7.2 documentation

# oceanum.datamesh.Query

pydantic model oceanum.datamesh.Query

  Datamesh query

  Fields

    - `aggregate (Optional[oceanum.datamesh.query.Aggregate])`

    - `crs (Optional[Union[str, int]])`

    - `datasource (str)`

    - `description (Optional[str])`

    - `geofilter (Optional[oceanum.datamesh.query.GeoFilter])`

    - `parameters (Optional[Dict])`

    - `timefilter (Optional[oceanum.datamesh.query.TimeFilter])`

    - `variables (Optional[List[str]])`

  field aggregate: Optional[Aggregate] = None

    Optional aggregation operators to apply to query after filtering

  field crs: Optional[Union[str, int]] = None

    Valid CRS string for returned data

  field datasource: str [Required]

    Datasource ID

    Constraints

      - maxLength = 80

      - minLength = 3

  field description: Optional[str] = None

    Human readable description of this query

  field geofilter: Optional[GeoFilter] = None
  field parameters: Optional[Dict] = {}

    Dictionary of driver parameters to pass to datasource

  field timefilter: Optional[TimeFilter] = None

    Temporal filter or interplator

  field variables: Optional[List[str]] = None

    List of requested variables.